#[non_exhaustive]pub enum ContentPart {
Text {
text: String,
},
Image {
image: ImageSource,
},
Document {
document: DocumentSource,
},
}Expand description
A single part of a user-visible or tool-result content array.
Provider-neutral. The motosan-ai adapter translates these into
motosan_ai::types::ContentBlock at dispatch time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Text
Plain UTF-8 text.
Image
An image, provided inline or by URL.
Fields
image: ImageSourceDocument
A document (e.g. PDF), provided inline or by URL.
Fields
document: DocumentSourceImplementations
Sourceimpl ContentPart
impl ContentPart
Sourcepub fn text(s: impl Into<String>) -> ContentPart
pub fn text(s: impl Into<String>) -> ContentPart
Convenience constructor for the common text case.
Sourcepub fn image_base64(
media_type: impl Into<String>,
data: impl Into<String>,
) -> ContentPart
pub fn image_base64( media_type: impl Into<String>, data: impl Into<String>, ) -> ContentPart
Convenience constructor for a base64-encoded image.
Sourcepub fn image_url(url: impl Into<String>) -> ContentPart
pub fn image_url(url: impl Into<String>) -> ContentPart
Convenience constructor for a URL image.
Sourcepub fn document_base64(
media_type: impl Into<String>,
data: impl Into<String>,
) -> ContentPart
pub fn document_base64( media_type: impl Into<String>, data: impl Into<String>, ) -> ContentPart
Convenience constructor for a base64-encoded document.
Sourcepub fn document_url(url: impl Into<String>) -> ContentPart
pub fn document_url(url: impl Into<String>) -> ContentPart
Convenience constructor for a URL document.
Sourcepub fn pdf_base64(data: impl Into<String>) -> ContentPart
pub fn pdf_base64(data: impl Into<String>) -> ContentPart
Convenience constructor for a base64-encoded PDF (media type fixed to application/pdf).
Sourcepub fn pdf_url(url: impl Into<String>) -> ContentPart
pub fn pdf_url(url: impl Into<String>) -> ContentPart
Convenience constructor for a PDF URL.
Sourcepub fn as_text(&self) -> Option<&str>
pub fn as_text(&self) -> Option<&str>
If this part is a Text, return its string. Non-text variants return None.
Sourcepub fn as_image(&self) -> Option<&ImageSource>
pub fn as_image(&self) -> Option<&ImageSource>
If this part is an Image, return its source.
Sourcepub fn as_document(&self) -> Option<&DocumentSource>
pub fn as_document(&self) -> Option<&DocumentSource>
If this part is a Document, return its source.