pub struct PermissionResolution {
pub tool: String,
pub args: Value,
pub choice: PermissionChoice,
}Expand description
User’s answer to a PermissionRequested prompt, carried back from the
front-end to the binary so the binary can update the session cache.
Fields
tool: Stringargs: Valuechoice: PermissionChoiceTrait Implementations
Sourceimpl Clone for PermissionResolution
impl Clone for PermissionResolution
Sourcefn clone(&self) -> PermissionResolution
fn clone(&self) -> PermissionResolution
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PermissionResolution
impl Debug for PermissionResolution
Sourceimpl<'de> Deserialize<'de> for PermissionResolution
impl<'de> Deserialize<'de> for PermissionResolution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PermissionResolution
impl PartialEq for PermissionResolution
Sourcefn eq(&self, other: &PermissionResolution) -> bool
fn eq(&self, other: &PermissionResolution) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PermissionResolution
impl Serialize for PermissionResolution
impl Eq for PermissionResolution
impl StructuralPartialEq for PermissionResolution