pub async fn dispatch_command(
registry: &ExtensionRegistry,
command_name: &str,
args: &str,
) -> CommandOutcomeExpand description
Dispatch a command event to the single owning extension.
pub async fn dispatch_command(
registry: &ExtensionRegistry,
command_name: &str,
args: &str,
) -> CommandOutcomeDispatch a command event to the single owning extension.